#
# spec file for package neomutt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           neomutt
Version:        20180323
Release:        lp150.1.3
Summary:        A command line mail reader based on Mutt
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Clients
Url:            https://www.neomutt.org
Source:         https://github.com/neomutt/neomutt/archive/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gawk
BuildRequires:  gdbm-devel
BuildRequires:  gettext
BuildRequires:  krb5-devel
BuildRequires:  libdb-4_8-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libgpgme-devel
BuildRequires:  libidn-devel
BuildRequires:  libkyotocabinet-devel
BuildRequires:  libtool
BuildRequires:  lmdb-devel
BuildRequires:  lua-devel
BuildRequires:  ncurses-devel
BuildRequires:  notmuch-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  w3m
BuildRequires:  xsltproc
BuildRequires:  zlib-devel
Recommends:     neomutt-doc
Recommends:     neomutt-lang

%description
NeoMutt is a command line mail reader based on Mutt, brings together many
new features. Can be installed in parallel with mutt.

%package doc
Summary:        Additional documentation for neomutt
Group:          Documentation/Other
Requires:       %{name} = %{version}
Recommends:     perl(Expect)
Provides:       %{name}:%{_docdir}/%{name}/COPYRIGHT
BuildArch:      noarch

%description doc
Documentation for neomutt with neomuttrc examples for different environments
and requirements.

%lang_package macro

%prep
%setup -q -n neomutt-%{name}-%{version}

%build
export CFLAGS="%{optflags}"
./configure	--prefix=%{_prefix}			\
		--docdir=%{_docdir}/neomutt	\
		--with-mailpath=%{_localstatedir}/mail	\
		--kyotocabinet			\
		--lua				\
		--lmdb				\
		--gnutls			\
		--gpgme				\
		--notmuch			\
		--sasl				\
		--gss				\
		--idn				\
		--mixmaster

make %{?_smp_mflags}

%install
%make_install

%find_lang neomutt

%files
%config(noreplace) %{_sysconfdir}/neomuttrc
%{_bindir}/neomutt
%{_mandir}/man1/neomutt.1%{ext_man}
%{_mandir}/man5/neomuttrc.5%{ext_man}
%dir %{_prefix}/libexec
%dir %{_prefix}/libexec/neomutt
%{_prefix}/libexec/neomutt/pgpewrap
%{_prefix}/libexec/neomutt/pgpring
%{_prefix}/libexec/neomutt/smime_keys
%{_mandir}/man1/pgpewrap_neomutt.1%{ext_man}
%{_mandir}/man1/pgpring_neomutt.1%{ext_man}
%{_mandir}/man1/smime_keys_neomutt.1%{ext_man}
%{_mandir}/man5/mbox_neomutt.5%{ext_man}
%{_mandir}/man5/mmdf_neomutt.5%{ext_man}
# this file is used from the default /etc/neomuttrc and moved from neomutt-doc
%dir %{_docdir}/neomutt
%doc %{_docdir}/neomutt/manual.txt

%files doc
%dir %{_docdir}/neomutt
%doc %{_docdir}/%{name}/COPYRIGHT
%doc %{_docdir}/%{name}/README*
%doc %{_docdir}/%{name}/ChangeLog.md
%doc %{_docdir}/%{name}/CODE_OF_CONDUCT.md
%dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/*.html
#%doc %{_docdir}/%{name}/*.txt
%doc %{_docdir}/neomutt/INSTALL
%doc %{_docdir}/neomutt/PGP-Notes.txt
%doc %{_docdir}/neomutt/mime.types
%doc %{_docdir}/neomutt/smime-notes.txt
%dir %doc %{_docdir}/%{name}/colorschemes/
%doc %{_docdir}/%{name}/colorschemes/*.neomuttrc
%dir %doc %{_docdir}/%{name}/keybase/
%doc %{_docdir}/%{name}/keybase/*
%dir %doc %{_docdir}/%{name}/logo/
%doc %{_docdir}/%{name}/logo/neomutt*
%dir %doc %{_docdir}/%{name}/samples/
%doc %{_docdir}/%{name}/samples/*.rc
%doc %{_docdir}/%{name}/samples/colors.*
%doc %{_docdir}/%{name}/samples/sample.*
%doc %{_docdir}/%{name}/samples/smime_keys_test.pl
%dir %doc %{_docdir}/%{name}/vim-keys/
%doc %{_docdir}/%{name}/vim-keys/*
%dir %doc %{_docdir}/%{name}/hcache-bench/
%doc %{_docdir}/%{name}/hcache-bench/README.md
%doc %{_docdir}/%{name}/hcache-bench/neomuttrc
%doc %{_docdir}/%{name}/hcache-bench/neomutt-hcache-bench.sh
%dir %doc %{_docdir}/%{name}/lua/
%doc %{_docdir}/%{name}/lua/test_lua-api_runner.neomuttrc
%doc %{_docdir}/%{name}/lua/test_lua-api_spec.lua
%doc %{_docdir}/neomutt/LICENSE.md

%files lang -f %{name}.lang

%changelog
* Fri Mar 23 2018 dsterba@suse.cz
- update to 20180323
  * Features
  - unify logging/messaging
  - add alert (blink) colors
  * Contrib
  - Vim syntax for NeoMutt log files
  * Bug Fixes
  - Fix progress bar range
  - notmuch: stop if db open fails
  - Improve index color cache flushing behavior
  - lua: fix crash when setting a string
  * Translations
  - Update Czech translation (100%%)
  - Update German translation (100%%)
  - Update Polish translation (94%%)
  - Update Portuguese (BR) translation (100%%)
  - Update Spanish translation (64%%)
  - Update Turkish translation (75%%)
  - Merge simliar messages
  * Docs
  - Clarify precedence of settings in config files
  - Fix subjectrx example in the manual
  * Website
  - Update Gentoo distro page
  - Devel: Static analysis
  * Build
  - Support —with-sysroot configure arg
  - Expose EXTRA_CFLAGS_FOR_BUILD and EXTRA_LDFLAGS_FOR_BUIlD
  - Update to latest autosetup
  - Make sure git_ver.h doesn't eat random 'g's out of tag names
  * Code
  - Refactor to reduce complexity
  - Refactor to reduce variables' scope
  - Sort functions/config to make docs more legible
* Wed Feb 28 2018 dsterba@suse.cz
- spec cleanup
- move manual.txt from neomutt-doc as it's bound to F1 key
* Fri Feb 23 2018 dsterba@suse.cz
- update to 20180223
  * Features
  - browser: `<goto-parent>` function bound to "p"
  - editor: `<history-search>` function bound to "Ctrl-r"
  - Cygwin support: https://www.neomutt.org/distro/cygwin
  - OpenSUSE support: https://www.neomutt.org/distro/suse
  - Upstream Homebrew support: Very soon - https://www.neomutt.org/distro/homebrew
  * Bug Fixes
  - gmail server-size search
  - nested-if: correctly handle "<" and ">" with %%?
  - display of special chars
  - lua: enable myvars
  - for pgpewrap in default gpg.rc
  - reply_regexp which wasn't formatted correctly.
  - parsing of urls containing '?'
  - out-of-bounds read in mutt_str_lws_len
  * Translations
  - Review fuzzy lt translations
  - Updated French translation
  * Website
  - Installation guide for Cygwin
  - Installation guide for OpenSUSE
  - Installation guide for CRUX
  * Build
  - check that DTDs are installed
  - autosetup improvements
  - option for which version of bdb to use
  - drop test for resizeterm -- it's always present
  * Code
  - split if's containing assignments
  - doxygen: add/improve comments
  - rename functions / parameters for consistency
  - add missing {}s for clarity
  - move functions to library
  - reduce scope of variables
  - boolify more variables
  - iwyu: remove unnecessary headers
  - name unicode chars
  - tailq: migrate parameter api
  - md5: refactor and tidy
  - rfc2047: refactor and tidy
  - buffer: improvements
  - create unit test framework
  - fix several coverity defects
  * Upstream
  - Fix s/mime certificate deletion bug
  - Disable message security if the backend is not available
  - Fix improper signed int conversion of IMAP uid and msn values
  - Change imap literal counts to parse and store unsigned ints
  - Fix imap status count range check
  - cmd_handle_fatal: make error message a bit more descriptive
  - Create pgp and s/mime default and sign_as key vars
  - Add missing setup calls when resuming encrypted drafts
  - mutt_pretty_size: show real number for small files
  - examine_directory: set directory/symlink size to zero
  - Add history-search function, bound to ctrl-r
  - Avoid a potential integer overflow if a Content-Length value is huge
* Fri Dec 29 2017 dsterba@suse.cz
- update to 2017-12-15
  - use autosetup instead of autotools
  - regression fixes
* Tue Nov 28 2017 dsterba@suse.cz
- neomutt 2017-12-08
